@@ -187,7 +187,7 @@ class CoinGeckoAPI:
         api_url = self.__api_url_params(api_url, kwargs)
 
         return self.__request(api_url)
-    
+
     @func_args_preprocessing
     def get_coin_ohlc_by_id(self, id, vs_currency, days, **kwargs):
         """Get coin's OHLC"""
@@ -229,6 +229,35 @@ class CoinGeckoAPI:
 
         return self.__request(api_url)
 
+    # ---------- ASSET PLATFORMS ----------#
+    @func_args_preprocessing
+    def get_asset_platforms(self, **kwargs):
+        """List all asset platforms (Blockchain networks)"""
+
+        api_url = '{0}asset_platforms'.format(self.api_base_url)
+        api_url = self.__api_url_params(api_url, kwargs)
+
+        return self.__request(api_url)
+
+    # ---------- CATEGORIES ----------#
+    @func_args_preprocessing
+    def get_coins_categories_list(self, **kwargs):
+        """List all categories"""
+
+        api_url = '{0}coins/categories/list'.format(self.api_base_url)
+        api_url = self.__api_url_params(api_url, kwargs)
+
+        return self.__request(api_url)
+
+    @func_args_preprocessing
+    def get_coins_categories(self, **kwargs):
+        """List all categories with market data"""
+
+        api_url = '{0}coins/categories'.format(self.api_base_url)
+        api_url = self.__api_url_params(api_url, kwargs)
+
+        return self.__request(api_url)
+
     # ---------- EXCHANGES ----------#
     @func_args_preprocessing
     def get_exchanges_list(self, **kwargs):
@@ -315,15 +344,24 @@ class CoinGeckoAPI:
 
         return self.__request(api_url)
 
-    #@func_args_preprocessing
-    #def get_indexes_by_id(self, id, **kwargs):
+    # @func_args_preprocessing
+    # def get_indexes_by_id(self, id, **kwargs):
     #    """Get market index by id"""
-
+    #
     #    api_url = '{0}indexes/{1}'.format(self.api_base_url, id)
     #    api_url = self.__api_url_params(api_url, kwargs)
-
+    #
     #    return self.__request(api_url)
 
+    @func_args_preprocessing
+    def get_indexes_by_market_id_and_index_id(self, market_id, id, **kwargs):
+        """Get market index by market id and index id"""
+
+        api_url = '{0}indexes/{1}/{2}'.format(self.api_base_url, market_id, id)
+        api_url = self.__api_url_params(api_url, kwargs)
+
+        return self.__request(api_url)
+
     @func_args_preprocessing
     def get_indexes_list(self, **kwargs):
         """List market indexes id and name"""
@@ -417,7 +455,7 @@ class CoinGeckoAPI:
         api_url = self.__api_url_params(api_url, kwargs)
 
         return self.__request(api_url)
-    
+
     # ---------- TRENDING ----------#
     @func_args_preprocessing
     def get_search_trending(self, **kwargs):
@@ -447,3 +485,12 @@ class CoinGeckoAPI:
 
         return self.__request(api_url)['data']
 
+    # ---------- COMPANIES ----------#
+    @func_args_preprocessing
+    def get_companies_public_treasury_by_coin_id(self, coin_id, **kwargs):
+        """Get public companies data"""
+
+        api_url = '{0}companies/public_treasury/{1}'.format(self.api_base_url, coin_id)
+        api_url = self.__api_url_params(api_url, kwargs)
+
+        return self.__request(api_url)
